[![PyPI version](https://badge.fury.io/py/OTSun.svg)](https://badge.fury.io/py/OTSun)

![OTSun logo](https://github.com/bielcardona/OTSun/raw/master/logo_OTSun.png)

# OTSun

OTSun is a python package that uses the Monte Carlo Forward Ray Tracing for the optical analysis of Solar Thermal Collectors and Solar Cells. 

## Installation

The package can be installed either from pypi:
`pip install otsun` or downloaded installed with `python setup.py install`.

In order to use the package the libraries of FreeCAD (https://www.freecadweb.org/) must be available and included in your python path.

## Documentation

The documentation of the module is available at http://otsun.readthedocs.io/

## How to cite OTSun?

If you need to cite OTSun, please use the following reference:

* Cardona G, Pujol-Nadal R (2020) OTSun, a python package for the optical analysis of solar-thermal collectors and photovoltaic cells with arbitrary geometry. PLoS ONE 15(10): e0240735. https://doi.org/10.1371/journal.pone.0240735
